[Libreoffice] [PATCH 3/3] Fix typos in comments in ure/cppuhelper

Laurent Charrière lcharriere at gmail.com
Wed Oct 13 22:28:41 PDT 2010


Signed-off-by: Laurent Charrière <lcharriere at gmail.com>
---
 cppuhelper/inc/cppuhelper/compbase_ex.hxx         |    2 +-
 cppuhelper/inc/cppuhelper/implbase.hxx            |    8 ++++----
 cppuhelper/inc/cppuhelper/implementationentry.hxx |   16 ++++++++--------
 cppuhelper/inc/cppuhelper/propshlp.hxx            |    6 +++---
 cppuhelper/inc/cppuhelper/stdidlclass.hxx         |    4 ++--
 cppuhelper/source/component.cxx                   |    2 +-
 cppuhelper/source/factory.cxx                     |    2 +-
 cppuhelper/source/interfacecontainer.cxx          |    6 +++---
 cppuhelper/source/propshlp.cxx                    |    4 ++--
 9 files changed, 25 insertions(+), 25 deletions(-)

diff --git a/cppuhelper/inc/cppuhelper/compbase_ex.hxx b/cppuhelper/inc/cppuhelper/compbase_ex.hxx
index 8d05f49..0a18567 100644
--- a/cppuhelper/inc/cppuhelper/compbase_ex.hxx
+++ b/cppuhelper/inc/cppuhelper/compbase_ex.hxx
@@ -45,7 +45,7 @@ class SAL_NO_VTABLE WeakComponentImplHelperBase
     , public ::com::sun::star::lang::XComponent
 {
 protected:
-    /** boradcast helper for disposing events
+    /** broadcast helper for disposing events
     */
     ::cppu::OBroadcastHelper rBHelper;
     
diff --git a/cppuhelper/inc/cppuhelper/implbase.hxx b/cppuhelper/inc/cppuhelper/implbase.hxx
index fcb5a8a..489e7b2 100644
--- a/cppuhelper/inc/cppuhelper/implbase.hxx
+++ b/cppuhelper/inc/cppuhelper/implbase.hxx
@@ -43,7 +43,7 @@ namespace cppu
 {
 
 /** Struct used for inline template implementation helpers: type entries.
-    Not for plublic use.
+    Not for public use.
     @internal
 */
 struct Type_Offset
@@ -56,7 +56,7 @@ struct Type_Offset
     typelib_InterfaceTypeDescription * pTD;
 };
 /** Struct used for inline template implementation helpers: class data of implementation.
-    Not for plublic use.
+    Not for public use.
     @internal
 */
 struct ClassDataBase
@@ -101,7 +101,7 @@ struct ClassDataBase
     There will be versions of this struct with varying arType2Offset[] array sizes, each of which
     is binary compatible with this one to be casted and used uniform. The size of the varying array
     is set in ClassDataBase::nType2Offset (base class).
-    Not for plublic use.
+    Not for public use.
     @internal
 */
 struct ClassData : public ClassDataBase
@@ -136,7 +136,7 @@ struct ClassData : public ClassDataBase
     */
     ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type > SAL_CALL getTypes()
         SAL_THROW( () );
-    /** Gets the class id of implemtation supporting com.sun.star.lang.XTypeProvider
+    /** Gets the class id of implementation supporting com.sun.star.lang.XTypeProvider
 
         @return class identifier (sequence< byte >)
     */
diff --git a/cppuhelper/inc/cppuhelper/propshlp.hxx b/cppuhelper/inc/cppuhelper/propshlp.hxx
index 61c8a22..2e89468 100644
--- a/cppuhelper/inc/cppuhelper/propshlp.hxx
+++ b/cppuhelper/inc/cppuhelper/propshlp.hxx
@@ -202,7 +202,7 @@ protected:
 private:
     void init( sal_Bool bSorted ) SAL_THROW( () );
 
-    /** The sequence generstet from the pProperties array. */
+    /** The sequence generated from the pProperties array. */
     ::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property > aInfos;
 
     /**
@@ -293,8 +293,8 @@ public:
         SAL_THROW( () );
 
     /**
-      Call disposing on all object in the container that
-      support XEventListener. Than clear the container.
+      Call disposing on all objects in the container that
+      support XEventListener. Then clear the container.
      */
     void	SAL_CALL disposeAndClear( const ::com::sun::star::lang::EventObject & rEvt ) SAL_THROW( () );
     /**
diff --git a/cppuhelper/inc/cppuhelper/stdidlclass.hxx b/cppuhelper/inc/cppuhelper/stdidlclass.hxx
index 902ec13..5facb34 100644
--- a/cppuhelper/inc/cppuhelper/stdidlclass.hxx
+++ b/cppuhelper/inc/cppuhelper/stdidlclass.hxx
@@ -46,10 +46,10 @@ namespace cppu {
 
 
 /**
-   Standardfunction to create an XIdlClass for a component.
+   Standard function to create an XIdlClass for a component.
    There is a function for each number of supported interfaces up to 10.
 
-   Since the switch to the final component model, there are no use cases anymore, where
+   Since the switch to the final component model, there are no use cases anymore where
    these functions should be used. Instead use the implementation helpers directly
    (see cppuhelper/implbase1.hxx).
 
diff --git a/cppuhelper/source/component.cxx b/cppuhelper/source/component.cxx
index a5ea645..3cc7c08 100644
--- a/cppuhelper/source/component.cxx
+++ b/cppuhelper/source/component.cxx
@@ -211,7 +211,7 @@ void OComponentHelper::dispose()
     }
     else
     {
-        // in a multithreaded environment, it can't be avoided,
+        // in a multithreaded environment, it can't be avoided
         // that dispose is called twice.
         // However this condition is traced, because it MAY indicate an error.
         OSL_TRACE( "OComponentHelper::dispose() - dispose called twice" );
diff --git a/cppuhelper/source/factory.cxx b/cppuhelper/source/factory.cxx
index d46e305..85f77d0 100644
--- a/cppuhelper/source/factory.cxx
+++ b/cppuhelper/source/factory.cxx
@@ -864,7 +864,7 @@ Reference< XInterface > ORegistryFactoryHelper::createModuleFactory()
             // one implementation found -> try to activate
             aLocation = xLocationKey->getAsciiValue();
 
-            // search protocol delemitter
+            // search protocol delimiter
             sal_Int32 nPos = aLocation.indexOf(
                 OUString( RTL_CONSTASCII_USTRINGPARAM("://") ) );
             if( nPos != -1 )
diff --git a/cppuhelper/source/interfacecontainer.cxx b/cppuhelper/source/interfacecontainer.cxx
index ca6a1e2..2d294ff 100644
--- a/cppuhelper/source/interfacecontainer.cxx
+++ b/cppuhelper/source/interfacecontainer.cxx
@@ -330,7 +330,7 @@ void OInterfaceContainerHelper::disposeAndClear( const EventObject & rEvt ) SAL_
     OSL_ENSURE( !bIsList || bInUse, "OInterfaceContainerHelper not in use" );
     if( !bIsList && pData )
         ((XInterface *)pData)->release();
-    // set the member to null, the iterator delete the values
+    // set the member to null, use the iterator to delete the values
     pData = NULL;
     bIsList = sal_False;
     bInUse = sal_False;
@@ -346,7 +346,7 @@ void OInterfaceContainerHelper::disposeAndClear( const EventObject & rEvt ) SAL_
         catch ( RuntimeException & )
         {
             // be robust, if e.g. a remote bridge has disposed already.
-            // there is no way, to delegate the error to the caller :o(.
+            // there is no way to delegate the error to the caller :o(.
         }
     }
 }
@@ -360,7 +360,7 @@ void OInterfaceContainerHelper::clear() SAL_THROW( () )
     OSL_ENSURE( !bIsList || bInUse, "OInterfaceContainerHelper not in use" );
     if( !bIsList && pData )
         ((XInterface *)pData)->release();
-    // set the member to null, the iterator delete the values
+    // set the member to null, use the iterator to delete the values
     pData = 0;
     bIsList = sal_False;
     bInUse = sal_False;
diff --git a/cppuhelper/source/propshlp.cxx b/cppuhelper/source/propshlp.cxx
index a193623..801b1c2 100644
--- a/cppuhelper/source/propshlp.cxx
+++ b/cppuhelper/source/propshlp.cxx
@@ -231,8 +231,8 @@ void OPropertySetHelper::disposing() SAL_THROW( () )
     EventObject aEvt;
     aEvt.Source = rSource;
 
-    // inform all listeners to reelease this object
-    // The listener container are automaticly cleared
+    // inform all listeners to release this object
+    // The listener containers are automatically cleared
     aBoundLC.disposeAndClear( aEvt );
     aVetoableLC.disposeAndClear( aEvt );
 }
diff --git a/cppuhelper/inc/cppuhelper/implementationentry.hxx b/cppuhelper/inc/cppuhelper/implementationentry.hxx
index f744932..6f5322d 100644
--- a/cppuhelper/inc/cppuhelper/implementationentry.hxx
+++ b/cppuhelper/inc/cppuhelper/implementationentry.hxx
@@ -24,8 +24,8 @@
  * for a copy of the LGPLv3 License.
  *
  ************************************************************************/
-#ifndef _CPPUHELPER_IMPLEMENATIONENTRY_HXX_
-#define _CPPUHELPER_IMPLEMENATIONENTRY_HXX_
+#ifndef _CPPUHELPER_IMPLEMENTATIONENTRY_HXX_
+#define _CPPUHELPER_IMPLEMENTATIONENTRY_HXX_
 
 #include <cppuhelper/factory.hxx>
 
@@ -36,21 +36,21 @@ namespace cppu
  */
 struct ImplementationEntry
 {
     /** Function, that creates an instance of the implemenation
      */
        ComponentFactoryFunc create;
 
     /** Function, that returns the implemenation-name of the implemenation
        (same as XServiceInfo.getImplementationName() ).
      */
      rtl::OUString ( SAL_CALL * getImplementationName )();
 
     /** Function, that returns all supported servicenames of the implemenation
        ( same as XServiceInfo.getSupportedServiceNames() ).
     */
      com::sun::star::uno::Sequence< rtl::OUString > ( SAL_CALL * getSupportedServiceNames ) ();
 
-    /** Function, that creates a SingleComponentFactory.
+    /** Function that creates a SingleComponentFactory.
     */
      ::com::sun::star::uno::Reference< ::com::sun::star::lang::XSingleComponentFactory >
      ( SAL_CALL * createFactory )(
@@ -59,7 +59,7 @@ struct ImplementationEntry
          ::com::sun::star::uno::Sequence< ::rtl::OUString > const & rServiceNames,
          rtl_ModuleCount * pModCount );
 
     /** The shared-library module-counter of the implemenation. Maybe 0. The module-counter
         is used during by the createFactory()-function.
     */
      rtl_ModuleCount * moduleCounter;
@@ -78,7 +78,7 @@ struct ImplementationEntry
                            This is a reference to the registry key, into which the implementation
                            data shall be written to.
     @param entries         Each element of the entries-array must contains a function pointer
-                           table for registering an implemenation. The end of the array 
+                           table for registering an implementation. The end of the array
                            must be marked with a 0 entry in the create-function.
     @return sal_True, if all implementations could be registered, otherwise sal_False.
  */
@@ -36,21 +36,21 @@ namespace cppu
 struct ImplementationEntry
 {
-    /** Function, that creates an instance of the implemenation
+    /** Function that creates an instance of the implementation
      */
        ComponentFactoryFunc create;
@@ -36,21 +36,21 @@ namespace cppu
        ComponentFactoryFunc create;
 
-    /** Function, that returns the implemenation-name of the implemenation
+    /** Function that returns the implementation-name of the implementation
        (same as XServiceInfo.getImplementationName() ).
      */
@@ -36,21 +36,21 @@ namespace cppu
      rtl::OUString ( SAL_CALL * getImplementationName )();
 
-    /** Function, that returns all supported servicenames of the implemenation
+    /** Function that returns all supported servicenames of the implementation
        ( same as XServiceInfo.getSupportedServiceNames() ).
     */
@@ -59,7 +59,7 @@ struct ImplementationEntry
          rtl_ModuleCount * pModCount );
 
-    /** The shared-library module-counter of the implemenation. Maybe 0. The module-counter
+    /** The shared-library module-counter of the implementation. Maybe 0. The module-counter
         is used during by the createFactory()-function.
     */
-- 
1.7.1



More information about the LibreOffice mailing list